@@ -6,7 +6,6 @@
 #include "packets.h"
 #include "crypto/chacha20poly1305.h"
 #include "crypto/blake2s.h"
-#include "crypto/siphash.h"
 #include "crypto/curve25519.h"
 
 #include <linux/version.h>
@@ -19,7 +18,7 @@ static int __init mod_init(void)
 	int ret;
 
 #ifdef DEBUG
-	if (!routing_table_selftest() || !packet_counter_selftest() || !curve25519_selftest() || !chacha20poly1305_selftest() || !blake2s_selftest() || !siphash_selftest())
+	if (!routing_table_selftest() || !packet_counter_selftest() || !curve25519_selftest() || !chacha20poly1305_selftest() || !blake2s_selftest())
 		return -ENOTRECOVERABLE;
 #endif
 	chacha20poly1305_init();
